pub trait Data:
DataTrait
+ Serialize
+ Debug
+ DowncastSync
+ Send
+ Sync {
// Required method
fn descriptor(&self) -> Arc<dyn DataDescriptor>;
}Required Methods
fn descriptor(&self) -> Arc<dyn DataDescriptor>
Implementations
Sourceimpl dyn Data
impl dyn Data
Sourcepub fn is<__T: Data>(&self) -> bool
pub fn is<__T: Data>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: Data>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: Data>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: Data>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: Data>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: Data>(&self) -> Option<&__T>
pub fn downcast_ref<__T: Data>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: Data>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: Data>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.